@@ -10,9 +10,13 @@ import sys
 import textwrap
 import threading
 import time
+from typing import Optional
 
 from cuvette.constants import CLUSTERS
 from cuvette.figlet import Figlet
+from cuvette.warning_utils import setup_cuvette_warnings
+
+setup_cuvette_warnings()
 
 SCRIPT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
@@ -27,6 +31,7 @@ beaker session create \
     --name {name} \
     {gpu_command} \
     {cluster_command} \
+    {hostname_command} \
     --image beaker://davidh/davidh-interactive \
     --workspace {workspace} \
     --priority {priority} \
@@ -56,6 +61,8 @@ beaker session create \
     --secret-env WANDB_API_KEY=davidh_WANDB_API_KEY \
     --secret-env lambda_AWS_ACCESS_KEY_ID=lambda_AWS_ACCESS_KEY_ID \
     --secret-env lambda_AWS_SECRET_ACCESS_KEY=lambda_AWS_SECRET_ACCESS_KEY \
+    --secret-env DOCKERHUB_USERNAME=davidh_DOCKERHUB_USERNAME \
+    --secret-env DOCKERHUB_TOKEN=davidh_DOCKERHUB_TOKEN \
     -- /entrypoint.sh\
 """
 
@@ -89,6 +96,12 @@ QUOTES = [
     "I think that the most exciting areas over the next five years will be really understanding text and videos. I will be disappointed if in five years’ time we do not have something that can watch a YouTube video and tell a story about what happened. In a few years time we will put [Deep Learning] on a chip that fits into someone’s ear and have an English-decoding chip that’s just like a real Babel fish. (Hinton, 2014 in a Reddit AMA)",  # https://www.reddit.com/r/MachineLearning/comments/2lmo0l/ama_geoffrey_hinton
     "Intellectually I think that NLP is fascinating, allowing us to focus on highly structured inference problems, on issues that go to the core of ‘what is thought’ but remain eminently practical, and on a technology that surely would make the world a better place (Michael Jordan, 2014)",  # https://watermark02.silverchair.com/coli_a_00239.pdf <- Referenced here
     "DL appears outwardly to be driven entirely by engineering concerns, but its connectionist roots are still strong and, as Pater documents, connectionism was founded on many of the same core principles as modern linguistics. Both fields can achieve more if they work together (Potts, 2018).",  # https://web.stanford.edu/~cgpotts/temp/pater-commentary-by-potts.pdf
+    "Verification, the key to AI (Sutton, 2001)", # https://dennyzhou.github.io/LLM-Reasoning-Stanford-CS-25.pdf#page=22
+    "The truth always turns out to be simpler than you thought. (Feynman)", # https://www.math.ucla.edu/~tao/quotes.html
+    "Meaning is not a unique property of language, but a general characteristic of human activity ... We cannot say that each morpheme or word has a single or central meaning, or even that it has a continuous or coherent range of meanings ... there are two separate uses and meanings of language – the concrete ... and the abstract (Harris, Distributional Structure 1954).)", # https://aclanthology.org/2020.emnlp-main.703
+    "In order to talk about concepts, we must understand the importance of mental models... we set up a model of the world which serves as a framework in which to organize our thoughts. We abstract the presence of particular objects, having properties, and entering into events and relationships (Winograd, 1971).", # https://aclanthology.org/2020.emnlp-main.703
+    "The risk of a wrong decision is preferable to the terror of indecision. (Maimonides, 1135-1204)", # https://youtu.be/G4_C5pyiS9A?t=1159
+    "Reports that say that something hasn't happened are always interesting to me, because as we know, there are known knowns; there are things we know we know. We also know there are known unknowns; that is to say we know there are some things we do not know. But there are also unknown unknowns—the ones we don't know we don't know. And if one looks throughout the history of our country and other free countries, it is the latter category that tends to be the difficult ones (Rumsfeld, 2002)", # https://en.wikipedia.org/wiki/There_are_unknown_unknowns
 ]
 
 
@@ -119,12 +132,7 @@ class ClusterSelector:
         random.shuffle(fonts)
         self.figlet.setFont(font=fonts[0])
         self.bg_color = curses.COLOR_BLACK
-        try:
-            import darkdetect  # pip install darkdetect
-
-            self.is_dark_mode = darkdetect.isDark()
-        except ImportError:
-            self.is_dark_mode = False
+        self.is_dark_mode = False
 
     def setup_colors(self):
         # Define colors based on theme
@@ -221,7 +229,41 @@ class ClusterSelector:
         )
         window.addstr(max_y - 1, left_offset, controls.center(display_width), curses.color_pair(2))
 
-    def draw_process_output(self, window, cluster_name: str, num_gpus: int):
+    def draw_process_output(
+        self, 
+        window, 
+        cluster_name: Optional[str|list] = None, 
+        host_name: Optional[str|list] = None, 
+        num_gpus: int = 0
+    ):
+        gpu_command = ""
+        if num_gpus > 0:
+            gpu_command = f"--gpus {num_gpus}"  # Use the selected number of GPUs
+
+        cluster_command = ""
+        if cluster_name is not None:
+            if not isinstance(cluster_name, list):
+                cluster_name = [cluster_name]
+            for _cluster_name in cluster_name:
+                cluster_command += f"--cluster {_cluster_name} "
+
+        hostname_command = ""
+        if host_name is not None:
+            if not isinstance(host_name, list):
+                host_name = [host_name]
+            for _host_name in host_name:
+                hostname_command += f"--hostname {_host_name} "
+
+        command = LAUNCH_COMMAND.format(
+            name=SESSION_NAME,
+            workspace=SESSION_WORKSPACE,
+            priority=SESSION_PRIORITY,
+            gpu_command=gpu_command,
+            cluster_command=cluster_command,
+            hostname_command=hostname_command,
+        )
+        command = command.replace("  ", " ")
+
         max_y, max_x = window.getmaxyx()
 
         # Clear screen but keep header
@@ -254,10 +296,10 @@ class ClusterSelector:
         )
 
         # Draw quick start command
-        if not isinstance(cluster_name, list):
-            cluster_name = [cluster_name]
         gpu_flag = f" -g {num_gpus}" if num_gpus > 0 else ""
-        quick_start = f"bl -c {' '.join(cluster_name)}{gpu_flag}"
+        cluster_flag = f" -c {' '.join(cluster_name)}" if cluster_name is not None else ""
+        host_flag = f" -H {' '.join(host_name)}" if host_name is not None else ""
+        quick_start = f"bl{cluster_flag}{host_flag}{gpu_flag}"
         window.addstr(
             header_height + 1,
             4,
@@ -284,23 +326,6 @@ class ClusterSelector:
             window.getch()
             return False
 
-        gpu_command = ""
-        if num_gpus > 0:
-            gpu_command = f"--gpus {num_gpus}"  # Use the selected number of GPUs
-
-        cluster_command = ""
-        for _cluster_name in cluster_name:
-            cluster_command += f"--cluster {_cluster_name} "
-
-        command = LAUNCH_COMMAND.format(
-            name=SESSION_NAME,
-            workspace=SESSION_WORKSPACE,
-            priority=SESSION_PRIORITY,
-            gpu_command=gpu_command,
-            cluster_command=cluster_command,
-        )
-        command = command.replace("  ", " ")
-
         output_queue = queue.Queue()
         spinner = itertools.cycle(["⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "⠦", "⠧", "⠇", "⠏"])
         last_spin_time = time.time()
@@ -553,9 +578,9 @@ class ClusterSelector:
         # Hide the cursor
         curses.curs_set(0)
 
-    def run_direct(self, stdscr, cluster_name, num_gpus):
+    def run_direct(self, stdscr, cluster_name, host_name, num_gpus):
         self.setup(stdscr)
-        self.draw_process_output(stdscr, cluster_name, num_gpus)
+        self.draw_process_output(stdscr, cluster_name, host_name, num_gpus)
 
     def run(self, stdscr):
         self.setup(stdscr)
@@ -585,7 +610,7 @@ class ClusterSelector:
             elif key in [ord(str(i)) for i in range(1, 9)]:  # Handle keys 1-8
                 num_gpus = int(chr(key))
                 _, cluster_name, _, _ = self.clusters[self.current_selection]
-                success = self.draw_process_output(stdscr, cluster_name, num_gpus)
+                success = self.draw_process_output(stdscr, cluster_name, None, num_gpus)
                 if success:
                     return self.clusters[self.current_selection][0]
                 else:
@@ -595,7 +620,7 @@ class ClusterSelector:
                 _, cluster_name, _, default_n_gpus = self.clusters[self.current_selection]
                 # Default to 1 GPU for GPU clusters, 0 for CPU clusters
                 num_gpus = default_n_gpus
-                success = self.draw_process_output(stdscr, cluster_name, num_gpus)
+                success = self.draw_process_output(stdscr, cluster_name, None, num_gpus)
                 if success:
                     return self.clusters[self.current_selection][0]
                 else:
@@ -667,16 +692,18 @@ def main():
     try:
         parser = argparse.ArgumentParser(description="Beaker Launch Tool")
         parser.add_argument("-c", "--clusters", nargs="+", help="Cluster names")
+        parser.add_argument("-H", "--hosts", nargs="+", help="Host names")
         parser.add_argument("-g", "--gpus", type=int, help="Number of GPUs")
         args = parser.parse_args()
 
         selector = ClusterSelector(max_width=100)
 
-        if args.clusters:
+        if args.clusters or args.hosts:
             # Direct launch with command line arguments
             success = curses.wrapper(
                 selector.run_direct,
                 args.clusters,
+                args.hosts,
                 args.gpus or 0,  # Default to no GPUs if not specified
             )
             if success and hasattr(selector, "final_output_lines"):
